@@ -321,7 +321,7 @@ def parseArg():
         pass
     arguments.add_argument('-f', "--traj", help="trajectory file(s). You can give a list of files.", required=True, nargs='+')
     arguments.add_argument('-t', '--top', help="topfile", default=None)
-    arguments.add_argument('-s', '--stride', help="stride (read every Xth frames", default=1)
+    arguments.add_argument('-s', '--stride', help="stride (read every Xth frames", default=1,type = int)
     arguments.add_argument('-l', '--logfile', help="logfile (default : clustering.log). The "
                                                    "name of your output file will be the basename (name before the extention "
                                                    "of this logfile", default="clustering")
@@ -789,7 +789,7 @@ def plot_barplot(clusters_list, logname, size, traj):
             if timeMax >= 1000:
                 timeMin = timeMin / 1000
                 timeMax = timeMax / 1000
-                plt.xlabel("Time (µs)")
+                plt.xlabel("Time ($\mu$s)")
         except:
             timeMin, timeMax = 0, np.shape(data)[1]
 
@@ -868,6 +868,7 @@ def plot_distmat(distances, logname):
     DESCRIPTION
     
     """
+
     fig, ax = plt.subplots()
 
     plt.imshow(distances, interpolation='none', origin='lower')
@@ -1081,10 +1082,10 @@ def generate_graphs(clusters_list, output, size, linkage, cutoff, distances, tra
     colors_list = plot_barplot(clusters_list, output, size, traj)
     plot_dendro(linkage, output, cutoff, colors_list, clusters_list)
     plot_hist(clusters_list, output, colors_list)
-    if (distances.shape[0] < 10000):
+    if (distances.shape[0] < 10002):
         plot_distmat(distances, output)
     else:
-        printScreenLogfile("Too many frames! The RMSD distance matrix will not be generated")
+        printScreenLogfile("Too many frames (>=10002)! The RMSD distance matrix will not be generated")
     return colors_list
 
 
